/*
  DHCP-based IP printer

  This sketch uses the DHCP extensions to the Ethernet library
  to get an IP address via DHCP and print the address obtained.
  using an Arduino Wiznet Ethernet shield.

  Circuit:
   Ethernet shield attached to pins 10, 11, 12, 13

  created 12 April 2011
  modified 9 Apr 2012
  by Tom Igoe
  modified 02 Sept 2015
  by Arturo Guadalupi

*/

#include <SPI.h>
#include <Ethernet2.h>
#include <EthernetUdp2.h>
#include <LiquidCrystal.h>

//  LCD Shield: 16 x 2 LCD Keypad Shield for Arduino
//  Manufacturer: LinkSprite
//  Suplier: Antratek
//  The LCD <> Arduino Uno connections:
//  LCD RS pin to digital pin 8
//  LCD Enable pin to digital pin 9
//  LCD D4 pin to digital pin 4
//  LCD D5 pin to digital pin 5
//  LCD D6 pin to digital pin 6
//  LCD D7 pin to digital pin 7
//  LCD R/W pin to ground
//  LCD VSS pin to ground
//  LCD VCC pin to 5V
//  Pin 10 must not connected. If it's connected the back light fickers.
//  Initialize the library by associating any needed LCD interface pin
//  with the arduino pin number it is connected to
const int rs = 8, en = 9, d4 = 4, d5 = 5, d6 = 6, d7 = 7;
LiquidCrystal lcd(rs, en, d4, d5, d6, d7);
//  Analog value of the 5 buttons on the LCD shield connected to Analog Input 0
int sensorValue;

//  Ethernet Set Up
//  Enter a MAC address for the Art-Net node == Arduino  + Ethernet shield
//  Newer Ethernet shields have a MAC address printed on a sticker on the shield
//  The MAC Address of your Ethernet shield
  byte mac[] = {0x90, 0xA2, 0xDA, 0x10, 0x1D, 0x6E};
//  Initialize the Ethernet client library
//  with the IP address and port of the server
//  that you want to connect to (port 80 is default for HTTP):
EthernetClient client;

void setup() {
//  set up the LCD's number of columns and rows:
  lcd.begin(16, 2);
  lcd.setCursor(0, 0);
//  Print a message to the LCD.
  lcd.print("My IP address: ");
//  Open serial communications and wait for port to open:
  Serial.begin(9600);
//  this check is only needed on the Leonardo:
  while (!Serial) {
    ; // wait for serial port to connect. Needed for native USB port only
  }

//  start the Ethernet connection:
  if (Ethernet.begin(mac) == 0) {
    Serial.println("Failed to configure Ethernet using DHCP");
//  no point in carrying on, so do nothing forevermore:
    for (;;)
      ;
  }
//  print your local IP address:
  printIPAddress();
}

void loop() {

  switch (Ethernet.maintain())
  {
    case 1:
//  renewed fail
      Serial.println("Error: renewed fail");
      break;

    case 2:
//  renewed success
      Serial.println("Renewed success");

//  print your local IP address:
      printIPAddress();
      break;

    case 3:
//  rebind fail
      Serial.println("Error: rebind fail");
      break;

    case 4:
//  rebind success
      Serial.println("Rebind success");

//  print your local IP address:
      printIPAddress();
      break;

    default:
//  nothing happened
      break;
  }
}

void printIPAddress() {
  Serial.print("My IP address: ");
  for (byte thisByte = 0; thisByte < 4; thisByte++) {
//  print the value of each byte of the IP address:
    Serial.print(Ethernet.localIP()[thisByte], DEC);
    Serial.print(".");
    if(thisByte == 0) {
      lcd.setCursor(0, 1);
      lcd.print(Ethernet.localIP()[thisByte], DEC);
    }
    if(thisByte == 1) {
      lcd.setCursor(3,1);
      lcd.print(".");
      lcd.setCursor(4,1);
      lcd.print(Ethernet.localIP()[thisByte], DEC);
    }
    if(thisByte == 2) {
      lcd.setCursor(7,1);
      lcd.print(".");
      lcd.setCursor(8,1);
      lcd.print(Ethernet.localIP()[thisByte], DEC);
    }
    if(thisByte == 3) {
      lcd.setCursor(11,1);
      lcd.print(".");
      lcd.setCursor(12,1);
      lcd.print(Ethernet.localIP()[thisByte], DEC);
    }
  }
  Serial.println();
}
